## Summary

<!-- Brief description of what this PR does -->

## Changes

-

## Type

- [ ] Bug fix
- [ ] New feature
- [ ] Performance improvement
- [ ] Documentation
- [ ] Refactoring

## Checklist

- [ ] Tests added/updated
- [ ] `pytest tests/ -m "not benchmark"` passes
- [ ] `cargo check` has no warnings
- [ ] Type stubs (`.pyi`) updated if API changed
- [ ] README updated if applicable
